<?php 
use Automattic\WooCommerce\GoogleListingsAndAds\API\Site\Controllers\EmptySchemaPropertiesTrait;

/*
* MI Data synchronization package
*/

if( ! defined( 'ABSPATH' ) ) {
    exit;
}

if( ! class_exists( 'Mi_save_settings' ) ) {

    class Mi_save_settings {

        public function mi_save_admin_field_settings() {

            check_admin_referer( 'mi_save_settings_field_verify' );

            if( ! current_user_can( 'manage_options' ) ) {
                wp_die( 'You are not allowed to settings' );
            }

            $mi_product_sync  = isset( $_POST['mi_product_sync'] ) ? sanitize_text_field( $_POST['mi_product_sync'] ) : "disabled";
            $mi_order_sync    = isset( $_POST['mi_order_sync'] ) ? sanitize_text_field( $_POST['mi_order_sync'] ) : "disabled" ;
            $mi_customer_sync = isset( $_POST['mi_customer_sync'] ) ? sanitize_text_field( $_POST['mi_customer_sync'] ) : "disabled";

            $values = array(
                'mi_product_sync'  => $mi_product_sync,
                'mi_order_sync'    => $mi_order_sync,
                'mi_customer_sync' => $mi_customer_sync,
            );
            
            // Creating a new webhook.
            $webhook = new WC_Webhook();

            $all         = WC_Data_Store::load( 'webhook' );
            $webhook_ids = $all->search_webhooks( ['status' => "active"] );
            
            $new_filtered_list = array();

            if( ! empty( $webhook_ids ) ) {

                $mi_webhook_names = array( 'Moon Invoice Product Create', 'Moon Invoice Customer Create', 'Moon Invoice Order Create' );

                $webhook_list = array_map( 'wc_get_webhook', $webhook_ids );
    
                foreach( $webhook_list as $details ){

                    if( in_array( $details->get_name(), $mi_webhook_names ) ) {

                        $new_filtered_list[] = [
                            'id'            => $details->get_id(),
                            'name'          => $details->get_name(),
                            'topic'         => $details->get_topic(),
                            'delivery_url'  => $details->get_delivery_url(),
                            'secret'        => $details->get_secret(),
                            'status'        => $details->get_status(),
                        ];
                    }
                }
            }

            // Product Webhook opertaion

            if( $mi_product_sync == 'enabled' ) {

                $name_index = array_search( 'Moon Invoice Product Create', array_column( $new_filtered_list, 'name' ) );
                
                if( empty( $name_index ) || $name_index == 0 ) {

                    $webhook->set_user_id( 1 ); // User ID used while generating the webhook payload.
                    $webhook->set_topic( 'product.created' ); // Event used to trigger a webhook.
                    $webhook->set_name( 'Moon Invoice Product Create' ); // Event used to trigger a webhook.
                    $webhook->set_secret( 'moon-invoice-product-create' ); // Secret to validate webhook when received.
                    $webhook->set_delivery_url( 'https://3cc2-171-50-244-142.ngrok.io/api/woocommerce/product-create' ); // URL where webhook should be sent.
                    $webhook->set_status( 'active' ); // Webhook status.
                    $webhook->save();
                }
            
            } else if( $mi_product_sync == 'disabled' ) {
                
                $name_index = array_search( 'Moon Invoice Product Create', array_column( $new_filtered_list, 'name' ) );

                if( ! empty( $name_index ) || $name_index == 0 ) {
                    
                    foreach( $new_filtered_list as $list ) {
    
                        if( $list['name'] == 'Moon Invoice Product Create' ) {
                            $webhook->set_id( $list['id'] );
                            $webhook->delete();
                        }
    
                    }
                }
            }

            // Order Webhook opertaion
            
            if( $mi_order_sync == 'enabled' ) {

                $name_index = array_search( 'Moon Invoice Order Create', array_column( $new_filtered_list, 'name' ) );
                
                if( empty( $name_index ) || $name_index == 0 ) {

                    $webhook->set_user_id( 1 ); // User ID used while generating the webhook payload.
                    $webhook->set_topic( 'order.created' ); // Event used to trigger a webhook.
                    $webhook->set_name( 'Moon Invoice Order Create' ); // Event used to trigger a webhook.
                    $webhook->set_secret( 'moon-invoice-order-create' ); // Secret to validate webhook when received.
                    $webhook->set_delivery_url( 'https://3cc2-171-50-244-142.ngrok.io/api/woocommerce/order-create' ); // URL where webhook should be sent.
                    $webhook->set_status( 'active' ); // Webhook status.
                    $webhook->save();
                }
            
            } else if( $mi_order_sync == 'disabled' ) {
                
                $name_index = array_search( 'Moon Invoice Order Create', array_column( $new_filtered_list, 'name' ) );

                if( ! empty( $name_index ) || $name_index == 0 ) {
                    
                    foreach( $new_filtered_list as $list ) {
    
                        if( $list['name'] == 'Moon Invoice Order Create' ) {
                            $webhook->set_id( $list['id'] );
                            $webhook->delete();
                        }
                    }
                }
            }

            // Customer Webhook opertaion
            
            if( $mi_customer_sync == 'enabled' ) {

                $name_index = array_search( 'Moon Invoice Customer Create', array_column( $new_filtered_list, 'name' ) );
                
                if( empty( $name_index ) || $name_index == 0 ) {

                    $webhook->set_user_id( 1 ); // User ID used while generating the webhook payload.
                    $webhook->set_topic( 'customer.created' ); // Event used to trigger a webhook.
                    $webhook->set_name( 'Moon Invoice Customer Create' ); // Event used to trigger a webhook.
                    $webhook->set_secret( 'moon-invoice-customer-create' ); // Secret to validate webhook when received.
                    $webhook->set_delivery_url( 'https://3cc2-171-50-244-142.ngrok.io/api/woocommerce/customer-create' ); // URL where webhook should be sent.
                    $webhook->set_status( 'active' ); // Webhook status.
                    $webhook->save();
                }
            
            } else if( $mi_customer_sync == 'disabled' ) {
                
                $name_index = array_search( 'Moon Invoice Customer Create', array_column( $new_filtered_list, 'name' ) );
                
                if( ! empty( $name_index ) || $name_index == 0 ) {
                    
                    foreach( $new_filtered_list as $list ) {
    
                        if( $list['name'] == 'Moon Invoice Customer Create' ) {
                            $webhook->set_id( $list['id'] );
                            $webhook->delete();
                        }
    
                    }
                }
            }

            update_option( "mi_settings", $values );
            wp_redirect( get_admin_url().'admin.php?page=mi_settings&success='.urlencode('Settings saved successfully.') );
            exit();
        }
    }
}

?>